django-webdav-storage
=====================

.. image:: https://badge.fury.io/py/django-webdav-storage.svg
    :target: https://badge.fury.io/py/django-webdav-storage

.. image:: https://img.shields.io/pypi/l/django-webdav-storage
    :target: https://raw.githubusercontent.com/marazmiki/django-webdav-storage/master/LICENSE
    :alt: The project license

.. image:: https://travis-ci.org/marazmiki/django-webdav-storage.svg?branch=master
    :target: https://travis-ci.org/marazmiki/django-webdav-storage
    :alt: Travis CI build status

.. image:: https://coveralls.io/repos/marazmiki/django-webdav-storage/badge.svg?branch=master
    :target: https://coveralls.io/r/marazmiki/django-webdav-storage?branch=master
    :alt: Code coverage percentage

.. image:: https://pypip.in/wheel/django-webdav-storage/badge.svg
     :target: https://pypi.python.org/pypi/django-webdav-storage/
     :alt: Wheel Status

.. image:: https://img.shields.io/pypi/pyversions/django-webdav-storage.svg
     :target: https://img.shields.io/pypi/pyversions/django-webdav-storage.svg
     :alt: Supported Python versions

.. image:: https://img.shields.io/pypi/djversions/django-webdav-storage.svg
     :target: https://pypi.org/project/django-webdav-storage/
     :alt: Supported Django versions

.. image:: https://readthedocs.org/projects/django-webdav-storage/badge/?version=latest
     :target: https://django-ulogin.readthedocs.io/ru/latest/?badge=latest
     :alt: Documentation Status

.. image:: https://api.codacy.com/project/badge/Grade/8eb2817e37cf4c2e98edc3dcbf886e6d
   :alt: Codacy Badge
   :target: https://app.codacy.com/manual/marazmiki/django-webdav-storage?utm_source=github.com&utm_medium=referral&utm_content=marazmiki/django-webdav-storage&utm_campaign=Badge_Grade_Dashboard


Description
-----------

This application allows you easily save media and static files into webdav storage.

Documentation
-------------
Please see full documentation at `Read the Docs <http://django-webdav-storage.readthedocs.io/en/latest/>`_

